# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['metadamage']

package_data = \
{'': ['*']}

install_requires = \
['PyPDF2>=1.26.0,<2.0.0',
 'about-time>=3.1.1,<4.0.0',
 'click-help-colors>=0.9,<0.10',
 'dask[distributed]>=2020.12.0,<2021.0.0',
 'dill>=0.3.3,<0.4.0',
 'fsspec>=0.8.5,<0.9.0',
 'joblib>=1.0.0,<2.0.0',
 'matplotlib>=3.3.3,<4.0.0',
 'numpyro>=0.4.1,<0.5.0',
 'pandas>=1.2.0,<2.0.0',
 'pip>=20.3.3,<21.0.0',
 'poetry-dynamic-versioning>=0.12.1,<0.13.0',
 'pyarrow>=2.0.0,<3.0.0',
 'rich>=9.8.1,<10.0.0',
 'typer[all]>=0.3.2,<0.4.0']

entry_points = \
{'console_scripts': ['metadamage = metadamage.cli:main_cli']}

setup_kwargs = {
    'name': 'metadamage',
    'version': '0.1.32',
    'description': 'Metagenomics Ancient Damage: metadamage',
    'long_description': '# Metadamage - Ancient Damage Estimation for Metagenomics\n\n[![PyPI](https://img.shields.io/pypi/v/metadamage)](https://pypi.org/project/metadamage) ![PyPI - License](https://img.shields.io/pypi/l/metadamage)\n\n---\n\n#### Work in progress. Please contact christianmichelsen@gmail.com for further information.\n\n---\n\n\nPersonal recommendations for this project:\n\n- Python Version: [Pyenv](https://github.com/pyenv/pyenv)\n- Virtual Environment:  [Virtualenv](https://github.com/pyenv/pyenv-virtualenv)\n- Package Management: [Poetry](https://python-poetry.org/)\n\nThis project requires a recent Python version (>=3.8) installed. See more [below](#setup).\n\n\n## <a name="install"></a> Installation:\n\nWith Poetry:\n```console\n$ poetry add metadamage\n```\nor, if you prefer regular pip:\n```console\n$ pip install metadamage\n```\n\n## <a name="cli"></a> Metadamage CLI:\n\nFor help on the CLI interface, `metadamage` provides a `help` function:\n\n```console\n$ metadamage --help\n```\n\nExample for running `metadamage` on a single file:\n```console\n$ metadamage --verbose --max-fits 10 --max-cores 2 ./data/input/data_ancient.txt\n```\n\n`metadamage` also allows to run on a multiple files:\n```console\n$ metadamage --verbose --max-fits 10 --max-cores 2 ./data/input/*.txt\n```\n\n## <a name="options"></a> Metadamage CLI Options:\n\nThe `metadamage` CLI has the following options.\n\n- Maximum values\n  - `--max-fits`: Maximum number of fits to do. Default is None, i.e. fit everything.\n  - `--max-plots`: Maximum number of plots to do. Default is None, i.e. plot everything that has to be fitted. Is always less than (or equal to) `max-fits`.\n  - `--max-cores`: Maximum number of cores to use while fitting. Default is 1.\n  - `--max-position`: Maximum position in the sequence to include. Default is +/- 15 (forward/reverse).\n\n- Minimum values or cuts/thresholds for plots\n  - `--min-damage`: Minimum threshold of damage (![D_\\mathrm{max}](https://render.githubusercontent.com/render/math?math=%5Clarge+%5Cdisplaystyle+D_%5Cmathrm%7Bmax%7D)\n) in the fit to be included in the plot. Default is None, i.e. to not make any cuts.\n  - `--min-sigma`: Minimum threshold of sigma (![n_\\sigma](https://render.githubusercontent.com/render/math?math=%5Clarge+%5Cdisplaystyle+n_%5Csigma)\n) in the fit to be included in the plot. Default is None, i.e. to not make any cuts.\n  - `--min-alignments`: Minimum number of alignments (![N_\\mathrm{alignments}](https://render.githubusercontent.com/render/math?math=%5Clarge+%5Cdisplaystyle+N_%5Cmathrm%7Balignments%7D)\n) in the sequence to be included in the plot. Default is None, i.e. to not make any cuts.\n\n- Other:\n  - `--sort-by`:     [`alignments`|`damage`|`sigma`]. Which order to sort the plots by when only plotting e.g. the top 10 plots. Default is `alignments` (which is also independent on the fit).\n\n- Boolean Flags\n  - `--verbose`: Prints out more information during the execution.\n  - `--force-reload-files`: Force reload the original datafile (and thus not load the autogenerated parquet file).\n  - `--force-fits`: Force remake the fits, even though the fit results already exist.\n  - `--force-plots`: Force recreate  the plots, even though the plots already exist.\n  - `--version`: Print the current version of the program and exit.\n\n\n<!-- [tex-image-link-generator](https://tex-image-link-generator.herokuapp.com/) -->\n<!-- https://gist.github.com/a-rodin/fef3f543412d6e1ec5b6cf55bf197d7b -->\n\n---\n\n## <a name="setup"></a> Setup Local Python Environment:\n\nMake sure you have a local Python environment. Personally, I recommend using Pyenv for installing Python versions and Pyenv-Virtualenv for easy managing of virtuel environments. See e.g. [this](https://github.com/pyenv/pyenv-installer#pyenv-installer) for easy installation of both.\n\nMake sure you have a decent Python version (>=3.8) installed:\n```console\n$ pyenv install 3.8.7\n```\n\nNow we set up a virtual environment, such that changes you do in this environment does not affect your other Python projects:\n```console\n$ pyenv virtualenv 3.8.7 metadamage38\n$ pyenv activate metadamage38\n```\n\nWe now use Poetry to setup a new project which uses metadamage. Follow the interactive guide:\n```console\n$ poetry new metadamage-folder\n$ cd metadamage-folder\n```\n\nInstead of activating the environment manually after every new login, we can tell `pyenv` to remember it for us:\n```console\n$ pyenv local metadamage38\n```\n\nWe now have a working local, virtual Python environment where the packages are managed by Poetry, so we can now add metadamamage to our project:\n```console\n$ poetry add metadamage\n```\n\nAt this point you should log out of your terminal and log in again for reloading everything. Now if you just write:\n\n```console\n$ metadamage\n```\n\nyou should see the following:\n\n```console\n$ metadamage\nUsage: metadamage [OPTIONS] FILENAMES...\nTry \'metadamage --help\' for help.\n\nError: Missing argument \'FILENAMES...\'.\n```\n\nwhich shows that it is working and installed. You can now use `metadamage --help` for more help (together with the variable explanations [above](#options)).\n\n---\n\n## <a name="update"></a> Update:\n\nWith Poetry:\n```console\n$ poetry update metadamage\n```\nor, if you prefer regular pip:\n```console\n$ pip install metadamage --upgrade\n```\n\n---\n\n## Conda:\n\nIf you prefer using Conda, you can also install `metadamage` (via pip). First create a folder:\n```console\n$ mkdir metadamage-conda\n$ cd metadamage-conda\n```\n\nTo install `metadamage`:\n```console\n$ wget https://raw.githubusercontent.com/ChristianMichelsen/metadamage/main/environment.yaml\n$ conda env create -f environment.yaml\n```\n\nTo update it to a new, released version of `metadamage`:\n```console\n$ wget https://raw.githubusercontent.com/ChristianMichelsen/metadamage/main/environment.yaml\n$ conda env update --file environment.yaml\n```\n\nFinally remember to activate the environment:\n```console\n$ conda activate metadamage\n```\n\n<!-- poetry add git+https://github.com/christianmichelsen/metadamage.git -->\n<!-- poetry add git+https://github.com/christianmichelsen/metadamage.git#develop -->\n',
    'author': 'Christian Michelsen',
    'author_email': 'christianmichelsen@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ChristianMichelsen/metadamage',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
